package com.jz.dmp.config;

import javax.sql.DataSource;

import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.ClassPathResource;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
/**
 * api数据库连接
 * @author pactera
 *
 */
//@Configuration
//@MapperScan(basePackages = DataSourceConfig2.PACKAGE, sqlSessionFactoryRef = "sqlSessionFactory2")
public class DataSourceConfig2 {
	
    static final String PACKAGE = "com.jz.dmp.web.ui.modules.api.repository";
    
    @Value("${spring.datasource2.driver-class-name}")
    private String driverClassName;
    @Value("${spring.datasource2.url}")
    private String url;
    @Value("${spring.datasource2.username}")
    private String userName;
    @Value("${spring.datasource2.password}")
    private String password;
    
    @Value("${spring.datasource2.hikari.connectionTimeout}")
    private long connectionTimeout;
    @Value("${spring.datasource2.hikari.idleTimeout}")
    private long idleTimeout;
    @Value("${spring.datasource2.hikari.maxLifetime}")
    private long maxLifetime;
    @Value("${spring.datasource2.hikari.maximumPoolSize}")
    private int maximumPoolSize;

    @Bean(name = "dataSource2")
    public DataSource dataSource2() {
    	 HikariConfig config = new HikariConfig();  
         config.setDriverClassName(driverClassName);  
         config.setJdbcUrl(url);  
         config.setUsername(userName);  
         config.setPassword(password);  
         config.setConnectionTimeout(connectionTimeout);   
         config.setIdleTimeout(idleTimeout);  
         config.setMaxLifetime(maxLifetime);  
         config.setMaximumPoolSize(maximumPoolSize);  
           
         HikariDataSource dataSource = new HikariDataSource(config);  
        return dataSource;
    }

    @Bean(name = "sqlSessionFactory2")
    public SqlSessionFactory sqlSessionFactory2(@Qualifier("dataSource2") DataSource dataSource) throws Exception {
        final SqlSessionFactoryBean sessionFactory = new SqlSessionFactoryBean();
        sessionFactory.setDataSource(dataSource);
        
        try {
            sessionFactory.setConfigLocation(new ClassPathResource("mybatis-config.xml"));
            
    		sessionFactory.setMapperLocations(new PathMatchingResourcePatternResolver()
    				.getResources("classpath:mapper/api/*.xml"));
            return sessionFactory.getObject();  
        } catch (Exception e) {
            throw new RuntimeException(e);  
        }
        
    }
    
    @Bean(name = "transactionManager2")    
    public DataSourceTransactionManager transactionManager2() {
        return new DataSourceTransactionManager(dataSource2());
    }
    
}
