package com.jz.dmp.modules.service.impl;


import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.common.persistence.BaseService;
import com.jz.common.utils.realTime.DBUtil;
import com.jz.common.utils.realTime.RestClient;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceNameListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeSyncListReq;
import com.jz.dmp.modules.controller.DataIntegration.bean.RealTimeTableInfoReq;
import com.jz.dmp.modules.dao.DmpProjectDao;
import com.jz.dmp.modules.dao.DmpRealtimeSyncHandleCountDao;
import com.jz.dmp.modules.dao.DmpRealtimeSyncInfoDao;
import com.jz.dmp.modules.model.*;
import com.jz.dmp.modules.service.DmpRealtimeSyncInfoService;
import freemarker.core.ParseException;
import freemarker.template.MalformedTemplateNameException;
import freemarker.template.Template;
import freemarker.template.TemplateException;
import freemarker.template.TemplateNotFoundException;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.web.servlet.view.freemarker.FreeMarkerConfig;

import java.io.IOException;
import java.io.StringWriter;
import java.util.*;
import java.util.regex.Pattern;

/**
 * 实时同步任务(DmpRealtimeSyncInfo)表服务实现类
 *
 * @author Bellamy
 * @since 2021-01-05 14:18:03
 */
@Service("dmpRealtimeSyncInfoService")
@Transactional
public class DmpRealtimeSyncInfoServiceImpl implements DmpRealtimeSyncInfoService {

    private static Logger logger = LoggerFactory.getLogger(DmpRealtimeSyncInfoServiceImpl.class);

    @Value("${spring.public-key}")
    private String publicKey;

    @Autowired
    private FreeMarkerConfig freeMarkerConfig;

    @Autowired
    private DmpRealtimeSyncInfoDao dmpRealtimeSyncInfoDao;

    @Autowired
    private DmpProjectDao dmpProjectDao;

    @Autowired
    private DmpRealtimeSyncHandleCountDao dmpRealtimeSyncHandleCountDao;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @Override
    public DmpRealtimeSyncInfo queryById(Integer id) {
        return this.dmpRealtimeSyncInfoDao.queryById(id);
    }

    /**
     * 查询多条数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    @Override
    public List<DmpRealtimeSyncInfo> queryAllByLimit(int offset, int limit) {
        return this.dmpRealtimeSyncInfoDao.queryAllByLimit(offset, limit);
    }

    /**
     * 新增数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 实例对象
     */
    @Override
    public DmpRealtimeSyncInfo insert(DmpRealtimeSyncInfo dmpRealtimeSyncInfo) {
        this.dmpRealtimeSyncInfoDao.insert(dmpRealtimeSyncInfo);
        return dmpRealtimeSyncInfo;
    }

    /**
     * 修改数据
     *
     * @param dmpRealtimeSyncInfo 实例对象
     * @return 实例对象
     */
    @Override
    public DmpRealtimeSyncInfo update(DmpRealtimeSyncInfo dmpRealtimeSyncInfo) {
        this.dmpRealtimeSyncInfoDao.update(dmpRealtimeSyncInfo);
        return this.queryById(dmpRealtimeSyncInfo.getId());
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRES_NEW)
    public boolean deleteById(Integer id) {
        return this.dmpRealtimeSyncInfoDao.deleteById(id) > 0;
    }

    /**
     * 实时同步任务列表分页查询
     *
     * @return
     * @author Bellamy
     */
    @Override
    public PageInfoResponse<RealTimeSyncListDto> queryRealTimeSyncListPage(RealTimeSyncListReq req) throws Exception {
        PageInfoResponse<RealTimeSyncListDto> pageInfoResponse = new PageInfoResponse<>();

        if (StringUtils.isNotEmpty(req.getSourceDatabaseName())) { //来源数据源名称
            req.setSourceDatabaseName(req.getSourceDatabaseName().trim());
        }
        if (StringUtils.isNotEmpty(req.getTargetDatabaseName())) { //目标源数据源名称
            req.setTargetDatabaseName(req.getTargetDatabaseName().trim());
        }
        if (StringUtils.isNotEmpty(req.getTreeId())) {
            //判断是否为整数 是整数返回true,否则返回false
            Pattern pattern = Pattern.compile("^[-\\+]?[\\d]*$");
            if (pattern.matcher(req.getTreeId().trim()).matches()) {
                req.setTreeId(req.getTreeId()); //id
            } else {
                req.setTreeName(req.getTreeId().trim());//节点名称
                req.setTreeId("");
            }
        }

        PageHelper.startPage(req.getPageNum(), req.getPageSize());
        List<RealTimeSyncListDto> list = dmpRealtimeSyncInfoDao.queryRealTimeSyncListPage(req);
        PageInfo<RealTimeSyncListDto> pageInfo = new PageInfo<>(list);

        pageInfoResponse.setCode(ResultCode.SUCCESS);
        pageInfoResponse.setMessage("查询成功");
        pageInfoResponse.setData(pageInfo);
        return pageInfoResponse;
    }

    /**
     * 根据多个实时任务id查询任务信息
     *
     * @return
     * @author Bellamy
     */
    @Override
    public List<DmpRealtimeSyncInfo> queryListById(String[] ids) throws Exception {
        return dmpRealtimeSyncInfoDao.queryListById(ids);
    }

    /**
     * 获取数据源和目标数据源下拉框
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    @Override
    public JsonResult<List<DataSourceNameListDto>> queryDatasourceNameList(String projectId, String type) throws Exception {
        List<DataSourceNameListDto> list = dmpRealtimeSyncInfoDao.queryDatasourceNameList(projectId, type);
        return new JsonResult(list);
    }

    /**
     * 新增--选择源表信息
     *
     * @return
     * @author Bellamy
     * @since 2021-01-06
     */
    @Override
    public JsonResult<RealTimeSyncModel> queryTableInfoByParams(RealTimeTableInfoReq req) throws Exception {
        Map<String, Map<String, String>> paramsMap = null;
        //根据来源数据源id获取数据信息
        RealTimeSyncDataSourceModel sourceDbInfo = dmpRealtimeSyncInfoDao.querygSourceDbInfoById(req.getSrcDatasourceId());
        sourceDbInfo.setPassword(new BaseService().decode(sourceDbInfo.getPassword(), publicKey));

        Map map = new HashMap();
        map.put("srcDatasourceId", req.getSrcDatasourceId());
        map.put("targetDatasourceId", req.getTargetDatasourceId());
        //数据源对应的表详细信息  判断表的记录在同步任务中是否存在记录,如果已经存在,说明同步过
        List<Map> list = dmpRealtimeSyncInfoDao.queryRealTimeInfoByDataSourceId(map);
        if (list.size() > 0 && list != null) {
            paramsMap = new HashMap<>();
            for (Map item : list) {
                String srcTableName = item.get("srcTableName").toString();
                paramsMap.put(srcTableName, item);
            }
        }
        Map<String, String> blackMapSetting = null;
        //查询来源数据源的黑名单表
        Map blackTableMap = dmpRealtimeSyncInfoDao.queryBlackTableByDataSourceId(req.getSrcDatasourceId());
        if (blackTableMap.size() > 0 && blackTableMap != null) {
            String blacklistTable = blackTableMap.get("blacklistTable").toString();
            if (StringUtils.isNotEmpty(blacklistTable)) {
                String[] blacklistTableArr = blacklistTable.split(",");
                if (blacklistTableArr.length > 0 && blacklistTableArr != null) {
                    blackMapSetting = new HashMap<>();
                    for (String str : blacklistTableArr) {
                        blackMapSetting.put(str, str);
                    }
                }
            }
        }
        //来源数据源下的表信息
        List<RealTimeSyncTableModel> dataSourceTables = DBUtil.getDataSourceTables(sourceDbInfo, req.getToQueryTableName(), true, paramsMap, req.getBlacklistTables(), req.getSelectTablesName(), blackMapSetting);

        RealTimeSyncModel realTimeSyncModel = new RealTimeSyncModel();
        realTimeSyncModel.setSrcdatasourceId(Integer.valueOf(req.getSrcDatasourceId()));
        realTimeSyncModel.setDataSourceName(sourceDbInfo.getDatasourceName());
        realTimeSyncModel.setDbName(sourceDbInfo.getDbName());
        realTimeSyncModel.setTables(dataSourceTables); //来源数据源下的表信息
        return new JsonResult(realTimeSyncModel);
    }

    /**
     * 新增--选择目标信息
     *
     * @return
     * @author Bellamy
     * @since 2021-01-07
     */
    @Override
    public JsonResult selectTargetDatasourceInfo(String projectId) throws Exception {
        DmpProjectSystemInfo dmpProjectSystemInfo = dmpProjectDao.queryProjectSystemInfo(Long.valueOf(projectId));
        String kafkaConnectUrl = dmpProjectSystemInfo.getKafkaConnectorUrl(); //kafka 连接信息
        String[] arr = kafkaConnectUrl.split(",");
        return new JsonResult(arr);
    }

    /**
     * 设置成黑名单时 ,检查是否有同步任务存在运行
     *
     * @return
     * @author Bellamy
     * @since 2021-01-07
     */
    @Override
    public JsonResult queryRealTimeInfoByDataSourceId(String srcDatasourceId, String sourceTableName) throws Exception {
        Map map = new HashMap();
        map.put("srcDatasourceId", srcDatasourceId); //来源表 数据源id
        map.put("sourceTableName", sourceTableName); // 来源表
        List<Map> list = dmpRealtimeSyncInfoDao.queryRealTimeInfoByDataSourceId(map);
        boolean flag = false;
        if (list.size() > 0 && list != null) {
            flag = true;
        }
        return new JsonResult(flag);
    }

    /**
     * 保存实时同步任务
     *
     * @return
     * @author Bellamy
     * @since 2021-01-08
     */
    @Override
    public boolean addRealTimeTask(Map<String, Object> params) throws Exception {
        String srcDataSourceId = params.get("srcDataSourceId").toString(); // 来源id
        String targetDataSourceId = (String) params.get("targetDataSourceId"); // 目标源id
        Long projectId = Long.valueOf(params.get("projectId").toString()); //项目id
        String connectorUrl = (String) params.get("connectorUrl"); //connectorUrl连接信息

        //根据来源数据源id获取数据信息
        RealTimeSyncDataSourceModel sourceDbInfo = dmpRealtimeSyncInfoDao.querygSourceDbInfoById(srcDataSourceId);
        if (sourceDbInfo != null) {
            throw new RuntimeException("来源数据设置信息不存在！");
        }
        sourceDbInfo.setPassword(new BaseService().decode(sourceDbInfo.getPassword(), publicKey));

        //根据目标数据源id获取数据信息
        RealTimeSyncDataSourceModel targetDbInfo = dmpRealtimeSyncInfoDao.querygSourceDbInfoById(targetDataSourceId);
        if (targetDbInfo != null) {
            throw new RuntimeException("目标数据源设置信息不存在！");
        }
        targetDbInfo.setPassword(new BaseService().decode(targetDbInfo.getPassword(), publicKey));

        //根据projectId查询项目系统配置信息
        DmpProjectSystemInfo dmpProjectSystemInfo = dmpProjectDao.queryProjectSystemInfo(projectId);
        params.put("connectorSecurityFlag", dmpProjectSystemInfo.getKerberosIsenable()); //安全验证开关,是否启用KERBEROS

        //保存实时同步任务处理数
        DmpRealtimeSyncHandleCount countModel = new DmpRealtimeSyncHandleCount();
        countModel.setUuid(UUID.randomUUID().toString());
        countModel.setToSubmit(1);
        countModel.setCreTime(new Date());
        //初始化当前任务记录数
        List<Map<String, String>> tables = (List<Map<String, String>>) params.get("tables");
        if (!CollectionUtils.isEmpty(tables)) {
            countModel.setToSubmit(countModel.getToSubmit() + tables.size());
        }
        dmpRealtimeSyncHandleCountDao.insert(countModel);
        logger.info("###################添加实时同步任务处理数结束{}" + countModel.toString() + "############");

        //connect1@http://172.18.104.130:9993/connectors
        if (StringUtils.isNotEmpty(connectorUrl)) {
            if (connectorUrl.contains("@")) {
                connectorUrl = connectorUrl.split("@")[1];
            }
        }
        //提交源到源的connector
        Integer datasource2DatasourceSyncId = submitDatasource2DatasourceToConnector(countModel.getUuid(), projectId, sourceDbInfo, targetDbInfo, dmpProjectSystemInfo, connectorUrl, params);

        return false;
    }

    private Integer submitDatasource2DatasourceToConnector(String uuid, Long projectId, RealTimeSyncDataSourceModel sourceDbInfo, RealTimeSyncDataSourceModel targetDbInfo, DmpProjectSystemInfo dmpProjectSystemInfo, String connectorUrl, Map<String, Object> params) {
        Integer srcDataSourceId = sourceDbInfo.getId();
        Integer targetDataSourceId = targetDbInfo.getId();

        //保存实时同步任务提交结果
        DmpRealtimeSyncSubmitResult dmpRealtimeSyncSubmitResult = new DmpRealtimeSyncSubmitResult();
        dmpRealtimeSyncSubmitResult.setUuid(uuid);
        dmpRealtimeSyncSubmitResult.setStatus(2);
        dmpRealtimeSyncSubmitResult.setType(1);
        dmpRealtimeSyncSubmitResult.setCreatedTime(new Date());
        dmpRealtimeSyncSubmitResult.setSubmitResult(sourceDbInfo.getDbName() + "----->" + sourceDbInfo.getDbName() + " 提交中");
        dmpRealtimeSyncHandleCountDao.insertRealtimeSyncSubmitResult(dmpRealtimeSyncSubmitResult);
        logger.info("###################添加实时同步任务提交结果 结束{}" + dmpRealtimeSyncSubmitResult.toString() + "############");

        DmpRealtimeSyncHandleCount handleCount = dmpRealtimeSyncHandleCountDao.queryById(uuid);
        if (handleCount != null) {
            handleCount.setToSubmit(handleCount.getToSubmit() - 1);
            handleCount.setSubmiting(handleCount.getSubmiting() + 1);
            dmpRealtimeSyncHandleCountDao.update(handleCount);
            logger.info("###################修改实时同步任务处理数--结束{}" + handleCount.toString() + "############");
        }

        //同步任务id
        Integer id = null;
        logger.info("同步数据源到数据源任务开始---");
        //源数据源到数据源同步connector信息  ----开始------
        //黑名单表
        String blacklistTables = "";
        String connectorBlacklistTables = "";
        int blacklistTableCount = 0;
        if (params.containsKey("blacklistTables")) {
            blacklistTables = (String) params.get("blacklistTables");
            if (StringUtils.isNotEmpty(blacklistTables)) {
                StringBuffer sb = new StringBuffer();
                String[] blacklistTableArr = blacklistTables.split(",");
                blacklistTableCount = blacklistTableArr.length;
                if (blacklistTableArr != null && blacklistTableCount >= 1) {
                    for (String string : blacklistTableArr) {
                        sb.append(sourceDbInfo.getDbName());
                        sb.append(".");
                        sb.append(string);
                        sb.append(",");
                    }
                }
                if (sb.toString().contains(",")) {
                    connectorBlacklistTables = sb.toString().substring(0, sb.toString().length() - 1);
                }
            }
        }
        logger.info("################### 解析黑名单表--结束" + connectorBlacklistTables + " ################");

        //白名单表
        String connectorWhitelistTables = "";
        int whitelistTablesConut = 0;
        if (params.containsKey("tables")) {
            List<Map<String, String>> tables = (List<Map<String, String>>) params.get("tables");
            if (!CollectionUtils.isEmpty(tables)) {
                whitelistTablesConut = tables.size();
                StringBuffer sb = new StringBuffer();
                for (Map<String, String> temp : tables) {
                    sb.append(sourceDbInfo.getDbName());
                    sb.append(".");
                    sb.append(temp.get("sourceTableName"));
                    sb.append(",");
                }
                if (sb.toString().contains(",")) {
                    connectorWhitelistTables = sb.toString().substring(0, sb.toString().length() - 1);
                }
            }
        }
        logger.info("################### 解析白名单表--结束 ################");

        Map<String, String> dataModelMap = new HashMap<>();

        dataModelMap.put("kafkaBootstrapServers", dmpProjectSystemInfo.getKafkaBootstrapServers());//kafka 地址
        dataModelMap.put("registerUrl", dmpProjectSystemInfo.getKafkaSchemaRegisterUrl()); //kafka connector schema 注册地址
        dataModelMap.put("blacklistTables", connectorBlacklistTables); //设置的黑名单表
        dataModelMap.put("blacklistTableCount", String.valueOf(blacklistTableCount)); //黑名单表数量
        //设置的白名单表   在模板里进行判比较黑名单表和白名单表的数量，谁小就用谁
        dataModelMap.put("whitelistTablesConut", String.valueOf(whitelistTablesConut)); //白名单表数量
        dataModelMap.put("connectorWhitelistTables", connectorWhitelistTables); //设置的白名单表
        //选择的来源数据信息
        dataModelMap.put("dbHost", sourceDbInfo.getHost());
        dataModelMap.put("dbPort", sourceDbInfo.getPort());
        dataModelMap.put("dbUserName", sourceDbInfo.getUserName());
        dataModelMap.put("dbPassWord", sourceDbInfo.getPassword());
        dataModelMap.put("dataSourceId", sourceDbInfo.getId().toString());
        dataModelMap.put("datasourceName", sourceDbInfo.getDatasourceName());
        dataModelMap.put("dbName", sourceDbInfo.getDbName());
        dataModelMap.put("connectorSecurityFlag", (String) params.get("connectorSecurityFlag")); //安全验证开关,是否启用KERBEROS

        //前端定义的sourceConnectorName前缀
        String sourceName = (String) params.get("sourceName");
        dataModelMap.put("sourceName", sourceName);
        //source kafak topic
        String topic = sourceDbInfo.getDatasourceName() + "_" + sourceName + "." + sourceDbInfo.getDbName() + ".databasehistory";
        dataModelMap.put("topic", topic);
        String sourceConnectorName = "debezium-connector-" + sourceDbInfo.getDatasourceName() + "_" + sourceName + "-" + sourceDbInfo.getDbName();

        // 自定义的sourceConnector参数  替换模板里的参数
        Map sourceCustomArgMap = (Map) params.get("sourceCustomArg");
        //查询同步任务信息表是否存在类型是数据源到数据源，srcDataSourceId，targetDataSourceId一样的信息  如果  存在就不发起请求
        Map<String, Object> queryParam = new HashMap<>();
        queryParam.put("srcDataSourceId", srcDataSourceId);
        queryParam.put("sourceConnectorName", sourceConnectorName);
        Map dataMap = dmpRealtimeSyncInfoDao.selecltRealtimeSyncInfoByParams(queryParam);
        if (dataMap.size() == 0 && dataMap.isEmpty()) { //不存在同一个数据源的同步任务 没查到信息
            logger.info("######不存在同一个数据源的同步任务srcDataSourceId="+srcDataSourceId+",type="+1+",sourceConnectorName="+sourceConnectorName+",connectorUrl="+connectorUrl+"的sourceConnector，添加新的");
            dataModelMap.put("name", sourceDbInfo.getDatasourceName()+"_"+ sourceName + "-" + sourceDbInfo.getDbName()); //source connector name

            String dataSource2DataSourceJsonStr = freemakerJson("source", dataModelMap); //使用freemaker模板生成 kafka connector 请求参数

            Map<String, Object> dataSource2DataSourceResult = RestClient.post(connectorUrl, dataSource2DataSourceJsonStr);
            String connectorJobId = getConnectorJobId(dataSource2DataSourceResult);
            //请求接口正常
            if (StringUtils.isNotEmpty(connectorJobId)) {
                DmpRealtimeSyncInfo saveBody = new DmpRealtimeSyncInfo();
                saveBody.setSrcDatasourceId(srcDataSourceId);
                saveBody.setSrcDatasourceName(sourceDbInfo.getDatasourceName());
                saveBody.setSrcDatabaseType(sourceDbInfo.getDataSourceTypeName());
                saveBody.setSrcDatabaseName(sourceDbInfo.getDbName());

                saveBody.setTargetDatasourceId(targetDataSourceId);
                saveBody.setTargetDatasourceName(targetDbInfo.getDatasourceName());
                saveBody.setTargetDatabaseType(targetDbInfo.getDataSourceTypeName());
                saveBody.setTargetDatabaseName(targetDbInfo.getDbName());

                saveBody.setType(1);
                saveBody.setStatus("SUBMIT_SUCCESS");
                saveBody.setConnectorJsonData(dataSource2DataSourceJsonStr);
                saveBody.setProjectId(projectId);
                saveBody.setConnectorUrl(connectorUrl);
                saveBody.setSrcTopicName(topic);
                saveBody.setSourceTypeName(sourceDbInfo.getDataSourceTypeName());
                saveBody.setTargetTypeName("Kafka");
                saveBody.setConnectorJobId(connectorJobId);
                saveBody.setConnectorJsonData(dataSource2DataSourceJsonStr);
               /* insertDmpRealtimeSyncInfoModel(saveBody);
                //操作数据源黑名单信息
                Map<String, Object> backlistTablesByDatasourceMap = dmpRealtimeSyncInfoDao.getBacklistTablesByDatasourceId(srcDataSourceId);
                if (CollectionUtils.isEmpty(backlistTablesByDatasourceMap)) {
                    dmpRealtimeSyncInfoDao.addBacklistTablesByDatasourceId(blacklistTables, srcDataSourceId);
                } else {
                    dmpRealtimeSyncInfoDao.updateBacklistTablesByDatasourceId(blacklistTables, srcDataSourceId);
                }

                //更新对应状态的数
                DmpRealtimeSyncHandleCountModel dmpRealtimeSyncHandleCountModelSuccess = dmpRealtimeSyncHandleCountDao.getDmpRealtimeSyncHandleCountModel(uuid);
                if (dmpRealtimeSyncHandleCountModelSuccess != null) {
                    dmpRealtimeSyncHandleCountModelSuccess.setSubmitSuccess(dmpRealtimeSyncHandleCountModelSuccess.getSubmitSuccess() + 1);
                    dmpRealtimeSyncHandleCountModelSuccess.setSubmiting(dmpRealtimeSyncHandleCountModelSuccess.getSubmiting() - 1);
                    dmpRealtimeSyncHandleCountDao.updateDmpRealtimeSyncHandleCountModel(dmpRealtimeSyncHandleCountModelSuccess);
                }
                //保存提交结果
                dmpRealtimeSyncSubmitResutModel.setSubmitResult(db2Db + " 提交成功");
                dmpRealtimeSyncSubmitResutModel.setStatus(3);
                dmpRealtimeSyncSubmitResutDao.addDmpRealtimeSyncSubmitResutModel(dmpRealtimeSyncSubmitResutModel);
                id = dmpRealtimeSyncInfoModel.getId();*/

            }
        }
        return 1;
    }

    /**
     * 使用freemaker模板生成 kafka connector 请求参数
     *
     * @param type      模板类型
     * @param dataModel 模板里定义的变量数据对象
     * @return
     */
    public String freemakerJson(String type, Map<String, String> dataModel) {
        StringWriter stringWriter = new StringWriter();
        try {

            Template template = freeMarkerConfig.getConfiguration().getTemplate("realtime-sync-connector/" + type + "_connector.ftl");
            if (template != null) {
                try {
                    template.process(dataModel, stringWriter);
                } catch (TemplateException e) {
                    e.printStackTrace();
                }
            }
        } catch (TemplateNotFoundException e) {
            e.printStackTrace();
        } catch (MalformedTemplateNameException e) {
            e.printStackTrace();
        } catch (ParseException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return stringWriter.toString();
    }

    /**
     * 根据返回结果  获取返回的connectorName
     *
     * @param resultMap
     * @return
     */
    public String getConnectorJobId(Map<String, Object> resultMap) {
        if (CollectionUtils.isEmpty(resultMap)) {
            return null;
        }
        if (!resultMap.containsKey("name")) {
            return null;
        }
        return (String) resultMap.get("name");
    }
}